@@ -1,7 +1,9 @@
 # weighted quantile
 weighted_quantile <- function(x, w, probs, na.rm = FALSE)
 {
-    dat <- .check(x, w, na.rm); if (is.null(dat)) return(NA)
+    dat <- .check_data_weights(x, w, na.rm)
+    if (is.null(dat))
+        return(NA)
     if (any(probs < 0) || any(probs > 1))
         stop("Argument 'probs' not in [0, 1]\n", call. = FALSE)
     res <- NULL
